@@ -11,7 +11,6 @@ import (
 	"github.com/mattn/go-colorable"
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/agent"
 	"github.com/superfly/flyctl/flypg"
 	"github.com/superfly/flyctl/internal/appconfig"
@@ -19,6 +18,8 @@ import (
 	"github.com/superfly/flyctl/internal/command/apps"
 	"github.com/superfly/flyctl/internal/command/ssh"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/flapsutil"
+	"github.com/superfly/flyctl/internal/flyutil"
 	mach "github.com/superfly/flyctl/internal/machine"
 	"github.com/superfly/flyctl/internal/watch"
 	"github.com/superfly/flyctl/iostreams"
@@ -62,7 +63,7 @@ func runFailover(ctx context.Context) (err error) {
 		MinPostgresStandaloneVersion = "0.0.7"
 
 		io      = iostreams.FromContext(ctx)
-		client  = fly.ClientFromContext(ctx)
+		client  = flyutil.ClientFromContext(ctx)
 		appName = appconfig.NameFromContext(ctx)
 	)
 
@@ -114,7 +115,7 @@ func runFailover(ctx context.Context) (err error) {
 		}
 	}
 
-	flapsClient := flaps.FromContext(ctx)
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
 	dialer := agent.DialerFromContext(ctx)
 
@@ -132,7 +133,6 @@ func runFailover(ctx context.Context) (err error) {
 			if err != nil {
 				return err
 			} else if machineRole(leader) == "leader" {
-
 				return fmt.Errorf("%s hasn't lost its leader role", leader.ID)
 			}
 			return nil
@@ -214,7 +214,7 @@ func flexFailover(ctx context.Context, machines []*fly.Machine, app *fly.AppComp
 		Signal: "SIGINT",
 	}
 
-	flapsClient := flaps.FromContext(ctx)
+	flapsClient := flapsutil.ClientFromContext(ctx)
 	err = flapsClient.Stop(ctx, machineStopInput, oldLeader.LeaseNonce)
 	if err != nil {
 		return fmt.Errorf("could not stop pg leader %s: %w", oldLeader.ID, err)
@@ -293,7 +293,7 @@ func flexFailover(ctx context.Context, machines []*fly.Machine, app *fly.AppComp
 
 func handleFlexFailoverFail(ctx context.Context, machines []*fly.Machine) (err error) {
 	io := iostreams.FromContext(ctx)
-	flapsClient := flaps.FromContext(ctx)
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
 	leader, err := pickLeader(ctx, machines)
 	if err != nil {
